"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Csdn = void 0;
const axios_1 = __importDefault(require("axios"));
const base_1 = require("../base");
const cheerio_1 = __importDefault(require("cheerio"));
const sitdown_1 = require("sitdown");
const decorator_1 = require("../../decorator");
const log_1 = require("../../log");
const sitdown = new sitdown_1.Sitdown({
    keepFilter: ['style'],
    codeBlockStyle: 'fenced',
    bulletListMarker: '-',
    hr: '---',
});
class Csdn extends base_1.Base {
    constructor(config) {
        super(config);
        this.headers = {
            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.138 Safari/537.36',
            accept: 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
            'accept-encoding': 'gzip, deflate, br',
            'accept-language': ' zh-CN,zh;q=0.9,en;q=0.8,en-US;q=0.7',
            'cache-control': 'no-cache',
            pragma: 'no-cache',
            'sec-fetch-dest': 'document',
            'sec-fetch-mode': 'navigate',
            'sec-fetch-site': 'none',
            'upgrade-insecure-requests': '1',
        };
        this.idTimeMap = new Map();
    }
    getMain() {
        return __awaiter(this, void 0, void 0, function* () {
            const idTimeMap = this.idTimeMap;
            let i = 1;
            const articleIds = [];
            while (i++) {
                const { data: html } = yield axios_1.default.get(`https://blog.csdn.net/${this.config.userId}/article/list/${i}`);
                const $ = cheerio_1.default.load(html);
                const list = $('.article-item-box');
                if ((list === null || list === void 0 ? void 0 : list.length) > 0) {
                    $('.article-item-box').each(function () {
                        const id = $('a', this)
                            .attr('href')
                            .match(/(\d{1,})$/);
                        if (id) {
                            articleIds.push(Number(id[0]));
                            idTimeMap.set(Number(id[0]), $('.date', this).text().trim());
                        }
                    });
                }
                else {
                    break;
                }
            }
            return articleIds;
        });
    }
    getByPage(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data: html } = yield axios_1.default.get(`https://blog.csdn.net/${this.config.userId}/article/details/${id}`);
            const tags = []; //标签
            const categories = []; //分类
            const $ = cheerio_1.default.load(html, {
                decodeEntities: true,
            });
            const title = $('.title-article').text();
            const x = $('#content_views').html();
            // csdn一个诡异的注释<!-- flowchart 箭头图标 勿删 -->
            const commentReg = /<!-- flowchart 箭头图标 勿删 -->/;
            if (!x) {
                return;
            }
            const markdown = sitdown.HTMLToMD(x).replace(commentReg, '');
            $('.artic-tag-box .tag-link').each(function (i) {
                if (i === 0) {
                    categories.push($(this).text());
                }
                else {
                    tags.push($(this).text());
                }
            });
            return {
                content: markdown,
                title,
                tags,
                categories,
                date: this.idTimeMap.get(id),
            };
        });
    }
    getByApi(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data: { data: { markdowncontent, content, tags: tagsStr, categories: categoriesStr, title, }, }, } = yield axios_1.default.get(`https://blog-console-api.csdn.net/v1/editor/getArticle?id=${id}`);
            const tags = []; //标签
            const categories = []; //分类
            if ((tagsStr === null || tagsStr === void 0 ? void 0 : tagsStr.length) > 0) {
                tags.push(...tagsStr.split(','));
            }
            if ((categoriesStr === null || categoriesStr === void 0 ? void 0 : categoriesStr.length) > 0) {
                categories.push(...categoriesStr.split(','));
            }
            return {
                content: markdowncontent || content || '',
                tags,
                categories,
                title,
                date: this.idTimeMap.get(id),
            };
        });
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const list = yield this.getMain();
            const resultList = [];
            let fn = null;
            if (this.config.cookie) {
                log_1.info('提供cookie，使用文章api获取模式');
                fn = this.getByApi;
            }
            else {
                log_1.info('未提供cookie 使用爬取页面模式，页面数据可能有错误');
                fn = this.getByPage;
            }
            for (let id of list) {
                log_1.info(`拉取:${id}`);
                let result = null;
                result = yield fn.call(this, id);
                resultList.push(result);
            }
            return resultList;
        });
    }
}
__decorate([
    decorator_1.throttle(1000),
    decorator_1.catchCount()
], Csdn.prototype, "getByPage", null);
__decorate([
    decorator_1.throttle(),
    decorator_1.catchCount()
], Csdn.prototype, "getByApi", null);
exports.Csdn = Csdn;
//# sourceMappingURL=index.js.map